==> haskell-asn1-parse-0.9.4-97-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-2XSdnWTi1Dc2fnIbZwGOPs
key: asn1-parse-0.9.4-2XSdnWTi1Dc2fnIbZwGOPs
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 4e902f030f171dbbed74a1a1e0a3018e
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-2XSdnWTi1Dc2fnIbZwGOPs
depends:
    asn1-encoding-0.9.5-BJSvqDJDx54IPJiXnFLbIv
    asn1-types-0.3.2-9EHsiBYRqUhKidaP0Vcp2k base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-98-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-3s9UgZukgy99QgEK5gDB3U
key: asn1-parse-0.9.4-3s9UgZukgy99QgEK5gDB3U
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 0bd848605c40602366c5cb96aed0d0ef
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-3s9UgZukgy99QgEK5gDB3U
depends:
    asn1-encoding-0.9.5-JlMVXuzAd3r1xeJzCIDfY5
    asn1-types-0.3.2-662ZFPfVm6V3hVAaeDyZld base-4.12.0.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
